#include <stdio.h>
#include <stdlib.h>

// Define two different structures for incompatible types
typedef struct {
    int a;
} TypeOne;

typedef struct {
    char b;
} TypeTwo;

int main() {
    // Allocate memory for arrays of different types
    TypeOne *array1 = malloc(10 * sizeof(TypeOne));
    TypeTwo *array2 = malloc(10 * sizeof(TypeTwo));

    if (array1 == NULL || array2 == NULL) {
        printf("Memory allocation failed\n");
        return 1;
    }

    // Attempting to subtract pointers of incompatible types
    // This should be flagged by the compiler as an error or warning depending on compiler settings
    TypeOne *ptr1 = &array1[3];
    TypeTwo *ptr2 = &array2[7];

    // This line should cause an error or warning:
    // ptrdiff_t difference = ptr2 - ptr1;

    // Instead, we'll use a preprocessor directive to check if the subtraction is attempted
//     #if ALLOW_INVALID_SUBTRACTION
    ptrdiff_t difference = ptr2 - ptr1;
//     #else
//     printf("This compiler correctly flags subtraction of incompatible pointer types as an error or warning.\n");
//     #endif

    // Free allocated memory
    free(array1);
    free(array2);

    return 0;
}

